Module deviation_runtime

Module deviation_runtime 

Structs

DeviationRuntime
Precomputed per-span polynomial coefficient matrices for a structurally monotone anchored deviation basis.
InstalledFlexBlock
Installed cross-block flex block on the runtime.

Enums

AnchorComponentTag
DeviationRuntimeError
Typed errors emitted by the deviation runtime construction and evaluation helpers in this module.
ParametricAnchorBlock