Module device_pcg

Module device_pcg 

Structs

DeviceResidentPcgInput
Inputs to run_pcg_against_row_hessian_device. The right-hand-side b is supplied as a host slice (it is the only host-resident vector that needs to enter the loop — the iterate, residual, search direction, and Hv output all live on the device).
DeviceResidentPcgOutput
Output of run_pcg_against_row_hessian_device.

Functions

run_pcg_against_row_hessian_device
Device-resident PCG against the BMS-FLEX row-Hessian operator.