pub struct ConformalInterval {
pub lo: f64,
pub hi: f64,
}Expand description
One maximal interval of candidate values retained in the prediction set. Endpoints may be infinite (honest unboundedness in low-information / high-leverage regimes).
Fields
lo: f64hi: f64Trait Implementations
Sourceimpl Clone for ConformalInterval
impl Clone for ConformalInterval
Sourcefn clone(&self) -> ConformalInterval
fn clone(&self) -> ConformalInterval
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConformalInterval
impl Debug for ConformalInterval
Sourceimpl PartialEq for ConformalInterval
impl PartialEq for ConformalInterval
Sourcefn eq(&self, other: &ConformalInterval) -> bool
fn eq(&self, other: &ConformalInterval) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ConformalInterval