pub fn sampleobservations<R: Rng + ?Sized>(
spec: &GenerativeSpec,
rng: &mut R,
) -> Result<Array1<f64>, EstimationError>Expand description
Draw one synthetic observation vector from a generative spec.
pub fn sampleobservations<R: Rng + ?Sized>(
spec: &GenerativeSpec,
rng: &mut R,
) -> Result<Array1<f64>, EstimationError>Draw one synthetic observation vector from a generative spec.