pub struct UnifiedFitResultParts {Show 28 fields
pub blocks: Vec<FittedBlock>,
pub training_sample_size: usize,
pub log_lambdas: ArrayBase<OwnedRepr<f64>, Dim<[usize; 1]>>,
pub lambdas: ArrayBase<OwnedRepr<f64>, Dim<[usize; 1]>>,
pub likelihood_family: Option<LikelihoodSpec>,
pub likelihood_scale: LikelihoodScaleMetadata,
pub log_likelihood_normalization: LogLikelihoodNormalization,
pub log_likelihood: f64,
pub deviance: f64,
pub reml_score: Option<f64>,
pub stable_penalty_term: f64,
pub penalized_objective: Option<f64>,
pub used_device: bool,
pub outer_iterations: usize,
pub outer_converged: bool,
pub outer_gradient_norm: Option<f64>,
pub standard_deviation: f64,
pub covariance_conditional: Option<ArrayBase<OwnedRepr<f64>, Dim<[usize; 2]>>>,
pub covariance_corrected: Option<ArrayBase<OwnedRepr<f64>, Dim<[usize; 2]>>>,
pub inference: Option<FitInference>,
pub fitted_link: FittedLinkState,
pub geometry: Option<FitGeometry>,
pub block_states: Vec<ParameterBlockState>,
pub pirls_status: PirlsStatus,
pub max_abs_eta: f64,
pub constraint_kkt: Option<ConstraintKktDiagnostics>,
pub artifacts: FitArtifacts,
pub inner_cycles: usize,
}Fields
blocks: Vec<FittedBlock>training_sample_size: usizeNumber of original training rows / experimental units. This is row count, not positive-weight count and not row count multiplied by the number of response coordinates.
log_lambdas: ArrayBase<OwnedRepr<f64>, Dim<[usize; 1]>>lambdas: ArrayBase<OwnedRepr<f64>, Dim<[usize; 1]>>likelihood_family: Option<LikelihoodSpec>likelihood_scale: LikelihoodScaleMetadatalog_likelihood_normalization: LogLikelihoodNormalizationlog_likelihood: f64deviance: f64reml_score: Option<f64>The fit’s REML/LAML criterion, or None when no finite criterion exists
at this fit (the exact-fit Gaussian boundary). See
UnifiedFitResult::reml_score.
stable_penalty_term: f64penalized_objective: Option<f64>Absent exactly when Self::reml_score is absent; the constructor
rejects any other pairing.
used_device: boolouter_iterations: usizeouter_converged: boolouter_gradient_norm: Option<f64>standard_deviation: f64covariance_conditional: Option<ArrayBase<OwnedRepr<f64>, Dim<[usize; 2]>>>covariance_corrected: Option<ArrayBase<OwnedRepr<f64>, Dim<[usize; 2]>>>inference: Option<FitInference>fitted_link: FittedLinkStategeometry: Option<FitGeometry>block_states: Vec<ParameterBlockState>pirls_status: PirlsStatusmax_abs_eta: f64constraint_kkt: Option<ConstraintKktDiagnostics>artifacts: FitArtifactsinner_cycles: usizeTrait Implementations
Sourceimpl Clone for UnifiedFitResultParts
impl Clone for UnifiedFitResultParts
Sourcefn clone(&self) -> UnifiedFitResultParts
fn clone(&self) -> UnifiedFitResultParts
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl !RefUnwindSafe for UnifiedFitResultParts
impl !UnwindSafe for UnifiedFitResultParts
impl Freeze for UnifiedFitResultParts
impl Send for UnifiedFitResultParts
impl Sync for UnifiedFitResultParts
impl Unpin for UnifiedFitResultParts
impl UnsafeUnpin for UnifiedFitResultParts