pub struct SurvivalMarginalSlopeOffsetGeometry {
pub baseline_config: SurvivalBaselineConfig,
pub theta: Array1<f64>,
pub offset_entry: Array1<f64>,
pub offset_exit: Array1<f64>,
pub derivative_offset_exit: Array1<f64>,
pub offset_entry_theta_first: Array2<f64>,
pub offset_exit_theta_first: Array2<f64>,
pub derivative_offset_exit_theta_first: Array2<f64>,
pub offset_entry_theta_second: Array3<f64>,
pub offset_exit_theta_second: Array3<f64>,
pub derivative_offset_exit_theta_second: Array3<f64>,
}Expand description
Rowwise value, gradient, and Hessian of the complete marginal-slope time offset with respect to a nonlinear survival-baseline chart.
The first-derivative arrays have shape n × d and the second-derivative
arrays have shape n × d × d, where d = theta.len(). The value arrays may
include a frozen non-baseline residual; that residual has zero derivatives.
Fields
baseline_config: SurvivalBaselineConfigtheta: Array1<f64>offset_entry: Array1<f64>offset_exit: Array1<f64>derivative_offset_exit: Array1<f64>offset_entry_theta_first: Array2<f64>offset_exit_theta_first: Array2<f64>derivative_offset_exit_theta_first: Array2<f64>offset_entry_theta_second: Array3<f64>offset_exit_theta_second: Array3<f64>derivative_offset_exit_theta_second: Array3<f64>Trait Implementations
Sourceimpl Clone for SurvivalMarginalSlopeOffsetGeometry
impl Clone for SurvivalMarginalSlopeOffsetGeometry
Sourcefn clone(&self) -> SurvivalMarginalSlopeOffsetGeometry
fn clone(&self) -> SurvivalMarginalSlopeOffsetGeometry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for SurvivalMarginalSlopeOffsetGeometry
impl RefUnwindSafe for SurvivalMarginalSlopeOffsetGeometry
impl Send for SurvivalMarginalSlopeOffsetGeometry
impl Sync for SurvivalMarginalSlopeOffsetGeometry
impl Unpin for SurvivalMarginalSlopeOffsetGeometry
impl UnsafeUnpin for SurvivalMarginalSlopeOffsetGeometry
impl UnwindSafe for SurvivalMarginalSlopeOffsetGeometry