Structs
- Device
Resident PcgInput - Inputs to
run_pcg_against_row_hessian_device. The right-hand-sidebis supplied as a host slice (it is the only host-resident vector that needs to enter the loop — the iterate, residual, search direction, and Hv output all live on the device). - Device
Resident PcgOutput - Output of
run_pcg_against_row_hessian_device.
Functions
- run_
pcg_ against_ row_ hessian_ device - Device-resident PCG against the BMS-FLEX row-Hessian operator.